
# Rock Paper Scissors Gameplay Logic (Python)


## Installation

Install from PyPI:

```sh
pip install s2t2-game-utils
```

## Usage

```py
from game_utils.rock_paper_scissors import *

print(WELCOME_MESSAGE) #> Hi. Welcome to my Rock-Paper-Scissors game!
```
